@@ -4,7 +4,7 @@ use warnings;
 package Printer::ESCPOS;
 
 # PODNAME: Printer::ESCPOS
-# ABSTRACT: Interface for all thermal or dot-matrix receipt printers that support ESC-POS specification.
+# ABSTRACT: Interface for all thermal, dot-matrix and other receipt printers that support ESC-POS specification.
 #
 # This file is part of Printer-ESCPOS
 #
@@ -13,7 +13,7 @@ package Printer::ESCPOS;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -112,12 +112,17 @@ sub _build_printer {
 
     my $base  = __PACKAGE__ . "::Profiles::";
     my $class = $base . $self->profile;
+
     Class::Load::load_class($class);
     unless ( $class->does(ESCPOSProfile) ) {
         confess
 "Class ${class} in ${base} does not implement the Printer::ESCPOS::Roles::Profile Interface";
     }
     my $object = $class->new( driver => $self->_driver, );
+
+    $object->init();
+
+    return $object;
 }
 
 no Moose;
@@ -131,14 +136,16 @@ __END__
 
 =head1 NAME
 
-Printer::ESCPOS - Interface for all thermal or dot-matrix receipt printers that support ESC-POS specification.
+Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printers that support ESC-POS specification.
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
+If you are just starting up with POS RECEIPT Printers, you must first refer to L<Printer::ESCPOS::Manual> to get started.
+
 Printer::ESCPOS provides four different types of printer connections to talk to a ESCPOS printer. 
 Among these connection types 'Serial', 'Network', 'File' are already implemented in this module. 'USB' type using L<Device::USB> module is under development. In the meantime most of the printing tasks for USB connected printer can be achieved using the 'File' connection mode for usb connected ESCPOS printers.
 
@@ -146,6 +153,10 @@ Among these connection types 'Serial', 'Network', 'File' are already implemented
  
      use Data::Dumper; # Just to get dumps of status functions.
  
+ 
+     #########################################################
+     BEGIN: Network Printer
+     #########################################################
      # For Network Printers $port is 9100 in most cases but might differ depending on how 
      # you have configured your printer
      my $device = Printer::ESCPOS->new(
@@ -175,6 +186,10 @@ Among these connection types 'Serial', 'Network', 'File' are already implemented
      $device->printer->print(); # Dispatch the above commands from module buffer to the Printer. 
                                 # This command takes care of read write buffers for the printer.
  
+ 
+     #########################################################
+     BEGIN: Serial Printer
+     #########################################################
      # Use the Serial mode for local printer connected on serial port(or a printer connected via 
      # a physical USB port in USB to Serial mode), check syslog(Usually under /var/log/syslog) 
      # for what device file was created for your printer when you connect it to your system(For 
@@ -186,10 +201,10 @@ Among these connection types 'Serial', 'Network', 'File' are already implemented
      );
      $device->printer->init(); # This calls the initialization functions for your printer.
  
-     say Dumper $printer_serial->printer->printerStatus();
-     say Dumper $printer_serial->printer->offlineStatus();
-     say Dumper $printer_serial->printer->errorStatus();
-     say Dumper $printer_serial->printer->paperSensorStatus();
+     say Dumper $device->printer->printerStatus();
+     say Dumper $device->printer->offlineStatus();
+     say Dumper $device->printer->errorStatus();
+     say Dumper $device->printer->paperSensorStatus();
  
      $device->printer->bold(1);
      $device->printer->write("Bold Text\n");
@@ -198,6 +213,10 @@ Among these connection types 'Serial', 'Network', 'File' are already implemented
  
      $device->printer->print();
  
+ 
+     #########################################################
+     BEGIN: File(Direct to Device File) Printer
+     #########################################################
      # A 'File' driver is similar to the 'Serial' driver in all functionality except that it 
      # doesn't support the status functions for the printer. i.e. you will not be able to use 
      # printerStatus, offlineStatus, errorStatus or paperSensorStatus functions
@@ -256,6 +275,18 @@ Use this attribute to send commands to the printer
     $device->printer->setFont('a');
     $device->printer->write("blah blah blah\n");
 
+=head1 MANUALS
+
+Refer to the following manuals for to get started with L<Printer::ESCPOS>
+
+=over
+
+=item *
+
+L<Printer::ESCPOS::Manual>
+
+=back
+
 =head1 NOTES
 
 =over
@@ -327,7 +358,7 @@ L<https://github.com/shantanubhadoria/perl-printer-escpos>
 
 =head1 AUTHOR
 
-Shantanu Bhadoria (shantanu@cpan.org)
+Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
 =head1 CONTRIBUTOR
 
