@@ -13,7 +13,7 @@ package Printer::ESCPOS::Connections::File;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 # Dependencies
 
@@ -60,7 +60,7 @@ Printer::ESCPOS::Connections::File - Bare Device File Connection Interface for P
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 ATTRIBUTES
 
@@ -70,7 +70,7 @@ This variable contains the path for the printer device file on UNIX-like systems
 
 =head1 AUTHOR
 
-Shantanu Bhadoria (shantanu@cpan.org)
+Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
 =head1 COPYRIGHT AND LICENSE
 
