@@ -13,7 +13,7 @@ package Printer::ESCPOS::Profiles::Generic;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -38,7 +38,7 @@ use constant {
 sub init {
     my ($self) = @_;
 
-    $self->driver->write( _ESC . '@' );
+    $self->driver->print( _ESC . '@' );
 }
 
 
@@ -46,10 +46,10 @@ sub enable {
     my ( $self, $n ) = @_;
 
     if ( $n == 1 ) {
-        $self->driver->write( _ESC . '=' . chr(1) );
+        $self->driver->print( _ESC . '=' . chr(1) );
     }
     else {
-        $self->driver->write( _ESC . '=' . chr(2) );
+        $self->driver->print( _ESC . '=' . chr(2) );
     }
 }
 
@@ -76,14 +76,14 @@ sub tabPositions {
 sub tab {
     my ($self) = @_;
 
-    $self->driver->write("\x09");
+    $self->driver->write("\t");
 }
 
 
 sub lf {
     my ($self) = @_;
 
-    $self->driver->write("\x0a");
+    $self->driver->write("\n");
 }
 
 
@@ -127,7 +127,7 @@ sub font {
 }
 
 
-sub emphasized {
+sub bold {
     my ( $self, $emphasized ) = @_;
 
     $self->emphasizedStatus($emphasized);
@@ -147,7 +147,33 @@ sub doubleStrike {
 }
 
 
-sub justification {
+sub underline {
+    my ( $self, $underline ) = @_;
+
+    $self->underlineStatus($underline);
+    if ( $self->usePrintMode ) {
+        $self->_updatePrintMode;
+    }
+    else {
+        $self->driver->write( _ESC . '-' . $underline );
+    }
+}
+
+
+sub invert {
+    my ( $self, $invert ) = @_;
+    $self->driver->write( _GS . 'B' . chr($invert) );
+}
+
+
+sub color {
+    my ( $self, $color ) = @_;
+
+    $self->driver->write( _ESC . 'r' . chr($color) );
+}
+
+
+sub justify {
     my ( $self, $j ) = @_;
 
     my %jmap = (
@@ -168,7 +194,7 @@ sub upsideDown {
 }
 
 
-sub height {
+sub fontHeight {
     my ( $self, $height ) = @_;
     my $width = $self->widthStatus;
 
@@ -182,7 +208,7 @@ sub height {
 }
 
 
-sub width {
+sub fontWidth {
     my ( $self, $width ) = @_;
     my $height = $self->heightStatus;
 
@@ -197,25 +223,6 @@ sub width {
 }
 
 
-sub underline {
-    my ( $self, $underline ) = @_;
-
-    $self->underlineStatus($underline);
-    if ( $self->usePrintMode ) {
-        $self->_updatePrintMode;
-    }
-    else {
-        $self->driver->write( _ESC . '-' . $underline );
-    }
-}
-
-
-sub invert {
-    my ( $self, $invert ) = @_;
-    $self->driver->write( _GS . 'B' . chr($invert) );
-}
-
-
 sub charSpacing {
     my ( $self, $spacing ) = @_;
     $self->driver->write( _ESC . _SP . chr($spacing) );
@@ -240,27 +247,10 @@ sub printPosition {
 }
 
 
-sub drawerKickPulse {
-    my ( $self, $pin, $time ) = @_;
-    $pin  = defined $pin  ? $pin  : 0;
-    $time = defined $time ? $time : 8;
-
-    $self->driver->write( _DLE . _DC4 . "\x01" . chr($pin) . chr($time) );
-}
-
-
-sub cutPaper {
+sub leftMargin {
     my ( $self, %params ) = @_;
-    $params{feed} = defined $params{feed} ? $params{feed} : 0;
-
-    $self->lf();
-    if ( $params{feed} == 0 ) {
-        $self->driver->write( _GS . 'V' . chr(1) );
-    }
-    else {
-        $self->driver->write( _GS . 'V' . chr(66) . chr(0) );
-    }
 
+    $self->driver->write( _GS . 'L' . chr( $params{nL} ) . chr( $params{nH} ) );
 }
 
 # This is a redundant function in ESCPOS which updates the printer
@@ -280,6 +270,57 @@ sub _updatePrintMode {
     $self->driver->write( _ESC . '!' . pack( "b*", $value ) );
 }
 
+# BEGIN: BARCODE functions
+
+
+sub barcode {
+    my ( $self, %params ) = @_;
+
+    my %map = (
+        none          => 0,
+        above         => 1,
+        below         => 2,
+        aboveandbelow => 3,
+    );
+    $self->driver->write(
+        _GS . 'H' . chr( $map{ $params{HRIPosition} || 'below' } ) );
+
+    %map = (
+        a => 0,
+        b => 1,
+    );
+    $self->driver->write( _GS . 'f' . chr( $map{ $params{font} || 'b' } ) );
+
+    $self->driver->write( _GS . 'h' . chr( $params{height} || 50 ) );
+
+    $self->driver->write( _GS . 'w' . chr( $params{width} || 2 ) );
+
+    %map = (
+        'UPC-A' => 0,
+        'UPC-B' => 1,
+        JAN13   => 2,
+        JAN8    => 3,
+        CODE39  => 4,
+        ITF     => 5,
+        CODABAR => 6,
+        CODE93  => 7,
+        CODE128 => 8,
+    );
+    $params{system} ||= 'CODE93';
+
+    if ( $map{ $params{system} } < 9 ) {
+        $self->driver->write( _GS . 'k'
+              . chr( $map{ $params{system} } + 65 )
+              . chr( length $params{barcode} )
+              . $params{barcode} );
+    }
+    else {
+        die "Invalid system in barcode";
+    }
+}
+
+# END: BARCODE functions
+
 # BEGIN: Bitmap printing methods
 
 
@@ -298,6 +339,34 @@ sub printImage {
 
 # END: Bitmap printing methods
 
+# BEGIN: Peripheral and cutter Control Commands
+
+
+sub cutPaper {
+    my ( $self, %params ) = @_;
+    $params{feed} = defined $params{feed} ? $params{feed} : 0;
+
+    $self->lf();
+    if ( $params{feed} == 0 ) {
+        $self->driver->write( _GS . 'V' . chr(1) );
+    }
+    else {
+        $self->driver->write( _GS . 'V' . chr(66) . chr(0) );
+    }
+
+}
+
+
+sub drawerKickPulse {
+    my ( $self, $pin, $time ) = @_;
+    $pin  = defined $pin  ? $pin  : 0;
+    $time = defined $time ? $time : 8;
+
+    $self->driver->write( _DLE . _DC4 . "\x01" . chr($pin) . chr($time) );
+}
+
+# End Peripheral Control Commands
+
 # BEGIN: Printer STATUS methods
 
 
@@ -396,57 +465,6 @@ sub inkStatusB {
 
 # END: Printer STATUS methods
 
-# BEGIN: BARCODE functions
-
-
-sub barcode {
-    my ( $self, %params ) = @_;
-
-    my %map = (
-        none          => 0,
-        above         => 1,
-        below         => 2,
-        aboveandbelow => 3,
-    );
-    $self->driver->write(
-        _GS . 'H' . chr( $map{ $params{HRIPosition} || 'below' } ) );
-
-    %map = (
-        a => 0,
-        b => 1,
-    );
-    $self->driver->write( _GS . 'f' . chr( $map{ $params{font} || 'b' } ) );
-
-    $self->driver->write( _GS . 'h' . chr( $params{height} || 50 ) );
-
-    $self->driver->write( _GS . 'w' . chr( $params{width} || 2 ) );
-
-    %map = (
-        'UPC-A' => 0,
-        'UPC-B' => 1,
-        JAN13   => 2,
-        JAN8    => 3,
-        CODE39  => 4,
-        ITF     => 5,
-        CODABAR => 6,
-        CODE93  => 7,
-        CODE128 => 8,
-    );
-    $params{system} ||= 'CODE93';
-
-    if ( $map{ $params{system} } < 9 ) {
-        $self->driver->write( _GS . 'k'
-              . chr( $map{ $params{system} } + 65 )
-              . chr( length $params{barcode} )
-              . $params{barcode} );
-    }
-    else {
-        die "Invalid system in barcode";
-    }
-}
-
-# END: BARCODE functions
-
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -462,18 +480,18 @@ Printer::ESCPOS::Profiles::Generic - Generic Profile for Printers for Printer::E
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 METHODS
 
 =head2 init
 
-Initializes the Printer. Clears the data in print buffer and resets the printer to the mode that was in effect when the power was turned on.
+Initializes the Printer. Clears the data in print buffer and resets the printer to the mode that was in effect when the power was turned on. This function is automatically called on creation of printer object.
 
 =head2 enable 
 
-Enables/Disables the printer with a '_ESC =' command (Set peripheral device). When disabled, the printer ignores all commands except enable() or other real-time commands
-pass 1 to enable, pass 0 to disable
+Enables/Disables the printer with a '_ESC =' command (Set peripheral device). When disabled, the printer ignores all commands except enable() or other real-time commands.
+Pass 1 to enable, pass 0 to disable
 
     $device->printer->enable(0) # disabled
     $device->printer->enable(1) # enabled
@@ -497,11 +515,21 @@ Sets horizontal tab positions for tab stops. Upto 32 tab positions can be set in
 
 =head2 tab 
 
-moves the cursor to next horizontal tab position like a "\t". This command is ignored unless the next horizontal tab position has been set.
+moves the cursor to next horizontal tab position like a "\t". This command is ignored unless the next horizontal tab position has been set. You may substitute this command with a "\t" as well.
+
+This
+
+    $device->printer->write("blah blah");
+    $device->printer->tab();
+    $device->printer->write("blah2 blah2");
+
+is same as this
+
+    $device->printer->write("blah blah\tblah2 blah2");
 
 =head2 lf
 
-line feed. This method will most likely not be used since you can simply insert a \n in your print string for write function to substitute for this function e.g. :
+line feed. Moves to the next line. You can substitute this method with {"\n"} in your print or write method e.g. :
 
 This
 
@@ -529,49 +557,104 @@ Cancel (delete) page data in page mode
 
 =head2 font
 
-Set Font style, you can pass 'a', 'b' or 'c'. Many printers don't support style 'c' and only have two supported styles.
+Set Font style, you can pass *a*, *b* or *c*. Many printers don't support style *c* and only have two supported styles.
 
-=head2 emphasized
+    $device->printer->font('a');
+    $device->printer->write('Writing in Font A');
+    $device->printer->font('b');
+    $device->printer->write('Writing in Font B');
 
-Set emphasized mode 0 for off and 1 for on
+=head2 bold 
+
+Set bold mode *0* for off and *1* for on. Also called emphasized mode in some printer manuals 
+
+    $device->printer->bold(1);
+    $device->printer->write("This is Bold Text\n");
+    $device->printer->bold(0);
+    $device->printer->write("This is not Bold Text\n");
 
 =head2 doubleStrike 
 
-Set double-strike mode 0 for off and 1 for on
+Set double-strike mode *0* for off and *1* for on
 
-=head2 justification 
-
-Set Justification. Options 'left', 'right' and 'center'
-
-    $self->printer->justification('right');
-
-=head2 upsideDown
-
-Sets Upside Down Printing on/off (pass 0 or 1)
-
-    $self->printer->upsideDownPrinting(1);
-
-=head2 height 
-
-Set font height. Only supports 0 or 1 for printmode set to 1, supports values 0 to 7 for non-printmode state (default) 
-
-=head2 width 
-
-Set font height. Only supports 0 or 1 for printmode set to 1, supports values 0 to 7 for non-printmode state (default) 
+    $device->printer->doubleStrike(1);
+    $device->printer->write("This is Double Striked Text\n");
+    $device->printer->doubleStrike(0);
+    $device->printer->write("This is not Double Striked  Text\n");
 
 =head2 underline
 
-set underline, 0 for off, 1 for on and 2 for double thickness 
+set underline, *0* for off, *1* for on and *2* for double thickness 
+
+    $device->printer->underline(1);
+    $device->printer->write("This is Underlined Text\n");
+    $device->printer->underline(2);
+    $device->printer->write("This is Underlined Text with thicker underline\n");
+    $device->printer->underline(0);
+    $device->printer->write("This is not Underlined Text\n");
 
 =head2 invert
 
-Reverse white/black printing mode pass 0 for off and 1 for on
+Reverse white/black printing mode pass *0* for off and *1* for on
 
+    $device->printer->invert(1);
+    $device->printer->write("This is Inverted Text\n");
     $device->printer->invert(0);
+    $device->printer->write("This is not Inverted Text\n");
+
+=head2 color
+
+Most thermal printers support just one color, black. Some ESCPOS printers(especially dot matrix) also support a second color, usually red. In many models, this only works when the color is set at the beginning of a new line before any text is printed. Pass *0* or *1* to switch between the two colors.
+
+    $device->printer->lf();
+    $device->printer->color(0); #black
+    $device->printer->write("black"); 
+    $device->printer->lf();
+    $device->printer->color(1); #red
+    $device->printer->write("Red"); 
+    $device->printer->print();
+
+=head2 justify 
+
+Set Justification. Options *left*, *right* and *center*
+
+    $device->printer->justify( 'right' );
+    $device->printer->write("This is right justified"); 
+
+=head2 upsideDown
+
+Sets Upside Down Printing on/off (pass *0* or *1*)
+
+    $device->printer->upsideDownPrinting(1);
+    $device->printer->write("This text is upside down"); 
+
+=head2 fontHeight 
+
+Set font height. Only supports *0* or *1* for printmode set to 1, supports values *0*,*1*,*2*,*3*,*4*,*5*,*6* and *7* for non-printmode state (default) 
+
+    $device->printer->fontHeight(1);
+    $device->printer->write("double height\n");
+    $device->printer->fontHeight(2);
+    $device->printer->write("triple height\n");
+    $device->printer->fontHeight(3);
+    $device->printer->write("quadruple height\n");
+    . . .
+
+=head2 fontWidth 
+
+Set font width. Only supports *0* or *1* for printmode set to 1, supports values *0*,*1*,*2*,*3*,*4*,*5*,*6* and *7* for non-printmode state (default) 
+
+    $device->printer->fontWidth(1);
+    $device->printer->write("double width\n");
+    $device->printer->fontWidth(2);
+    $device->printer->write("triple width\n");
+    $device->printer->fontWidth(3);
+    $device->printer->write("quadruple width\n");
+    . . .
 
 =head2 charSpacing
 
-Sets charachter spacing takes a value between 0 and 255
+Sets character spacing takes a value between 0 and 255
 
     $device->printer->charSpacing(5);
     $device->printer->write("Blah Blah Blah\n");
@@ -579,7 +662,9 @@ Sets charachter spacing takes a value between 0 and 255
 
 =head2 lineSpacing 
 
-    $device->printer->lineSpacing($spacing)
+Sets the spacing between each line of printout.
+
+    $device->printer->lineSpacing($spacing);
 
 * 0 <= spacing <= 255
 
@@ -587,39 +672,82 @@ Sets charachter spacing takes a value between 0 and 255
 
 Revert to default Line spacing for the printer
 
+    $device->printer->selectDefaultLineSpacing();
+
 =head2 printPosition
 
 Sets the distance from the beginning of the line to the position at which characters are to be printed.
+
     $device->printer->printPosition( $length, $height );
 
 * 0 <= $length <= 255
 * 0 <= $height <= 255
 
-=head2 drawerKickPulse
+=head2 leftMargin
 
-Trigger drawer kick
+Sets the left margin code to the printer. takes two single byte parameters, ~nL~ and ~nH~.
+To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number) part of a number, while MOD indicates the
+remainder of a division operation. Must be sent before a new line begins to be effective.
+For example, to break the value 520 into two bytes, use the following two equations:
+~nH~ = INT 520/256
+~nL~ = MOD 520/256
 
-    $device->printer->drawerKickPulse( $pin, $time );
+    $device->printer->leftMargin(nL => $nl, nH => $nh);
 
-* $pin is either 0( for pin 2 ) and 1( for pin5 ) default value is 0
-* $time is a value between 1 to 8 and the pulse duration in multiples of 100ms. default value is 8
+=head2 barcode
 
-For default values use without any params to kick drawer pin 2 with a 800ms pulse
+This method prints a barcode to the printer. This can be bundled with other text formatting commands at the appropriate point where you would like to print a barcode on your print out. takes argument ~barcode~ as the barcode value.
 
-    $device->printer->drawerKickPulse();
+In the simplest form you can use this command as follows:
 
-=head2 cutPaper
+    #Default barcode printed in code93 system with a width of 2 and HRI Chars printed below the barcode
+    $device->printer->barcode(
+        barcode     => 'SHANTANU BHADORIA',
+    );
 
-Cuts the paper, if feed is set to 0 then printer doesnt feed paper to cutting position before cutting it. The default behavior is that the printer doesn't feed paper to cutting position before cutting. One pre-requisite line feed is automatically executed before paper cut.
+However there are several customizations available including barcode ~system~, ~font~, ~height~ etc.
 
-    $device->printer->cutPaper( feed => false )
+    my $hripos = 'above';
+    my $font   = 'a';
+    my $height = 100;
+    my $system = 'UPC-A';
+    $device->printer->barcode(
+        HRIPosition => $hripos,        # Position of Human Readable characters
+                                       # 'none','above','below','aboveandbelow'
+        font        => $font,          # Font for HRI characters. 'a' or 'b'
+        height      => $height,        # no of dots in vertical direction
+        system      => $system,        # Barcode system
+        width       => 2               # 2:0.25mm, 3:0.375mm, 4:0.5mm, 5:0.625mm, 6:0.75mm
+        barcode     => '123456789012', # Check barcode systems for allowed value
+    );
+    $device->printer->barcode(
+        system      => 'CODE39',
+        HRIPosition => 'above',
+        barcode     => '*1-I.I/ $IA*',
+    );
+    $device->printer->barcode(
+        system      => 'CODE93',
+        HRIPosition => 'above',
+        barcode     => 'Shan',
+    );
+
+Available systems:
+
+* UPC-A
+* UPC-C
+* JAN13
+* JAN8
+* CODE39
+* ITF
+* CODABAR
+* CODE93  
+* CODE128 
 
 =head2 printNVImage
 
 Prints bit image stored in Non-Volatile (NV) memory of the printer. 
-This function also writes the buffer data to the printer before printing the bit image. 
 
-    $self->printer->printNVImage($flag);
+    $device->printer->printNVImage($flag);
 
 * $flag = 0 # Normal width and Normal Height
 * $flag = 1 # Double width and Normal Height
@@ -631,13 +759,36 @@ This function also writes the buffer data to the printer before printing the bit
 Prints bit image stored in Volatile memory of the printer. This image gets erased when printer is reset. 
 This function also writes the buffer data to the printer before printing the bit image. 
 
-    $self->printer->printImage($flag);
+    $device->printer->printImage($flag);
 
 * $flag = 0 # Normal width and Normal Height
 * $flag = 1 # Double width and Normal Height
 * $flag = 2 # Normal width and Double Height
 * $flag = 3 # Double width and Double Height
 
+=head2 cutPaper
+
+Cuts the paper, if ~feed~ is set to *0* then printer doesnt feed paper to cutting position before cutting it. The default behavior is that the printer doesn't feed paper to cutting position before cutting. One pre-requisite line feed is automatically executed before paper cut though.
+
+    $device->printer->cutPaper( feed => 0 )
+
+While not strictly a text formatting option, in receipt printer the cut paper instruction is sent along with the rest of the text and text formatting data and the printer cuts the paper at the appropriate points wherever this command is used.
+
+=head2 drawerKickPulse
+
+Trigger drawer kick. Used to open cash drawer connected to the printer. In some use cases it may be used to trigger other devices by close contact.
+
+    $device->printer->drawerKickPulse( $pin, $time );
+
+* $pin is either 0( for pin 2 ) and 1( for pin5 ) default value is 0
+* $time is a value between 1 to 8 and the pulse duration in multiples of 100ms. default value is 8
+
+For default values use without any params to kick drawer pin 2 with a 800ms pulse
+
+    $device->printer->drawerKickPulse();
+
+Again like cutPaper command this is obviously not a text formatting command but this command is sent along with the rest of the text and text formatting data and the printer sends the pulse at the appropriate points wherever this command is used. While originally designed for triggering a cash drawer to open, in practice this port can be used for all sorts of devices like pulsing light, or sound alarm etc.
+
 =head2 printerStatus
 
 Returns printer status in a hashref.
@@ -702,52 +853,9 @@ Only available for dot-matrix and other ink consuming printers. Gets printer ink
         ink_cartridge_missing => $flags[2],
     };
 
-=head2 barcode
-
-    my $hripos = 'above';
-    my $font   = 'a';
-    my $height = 100;
-    my $system = 'UPC-A';
-    $device->printer->barcode(
-        HRIPosition => $hripos,        # Position of Human Readable characters
-                                       # 'none','above','below','aboveandbelow'
-        font        => $font,          # Font for HRI characters. 'a' or 'b'
-        height      => $height,        # no of dots in vertical direction
-        system      => $system,        # Barcode system
-        width       => 2               # 2:0.25mm, 3:0.375mm, 4:0.5mm, 5:0.625mm, 6:0.75mm
-        barcode     => '123456789012', # Check barcode systems for allowed value
-    );
-    $device->printer->barcode(
-        system      => 'CODE39',
-        HRIPosition => 'above',
-        barcode     => '*1-I.I/ $IA*',
-    );
-    $device->printer->barcode(
-        system      => 'CODE93',
-        HRIPosition => 'above',
-        barcode     => 'Shan',
-    );
-
-    #Default barcode printed in code93 width 2 and HRI Chars below the barcode
-    $device->printer->barcode(
-        barcode     => 'SHANTANU BHADORIA',
-    );
-
-Available systems:
-
-* UPC-A
-* UPC-C
-* JAN13
-* JAN8
-* CODE39
-* ITF
-* CODABAR
-* CODE93  
-* CODE128 
-
 =head1 AUTHOR
 
-Shantanu Bhadoria (shantanu@cpan.org)
+Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
 =head1 COPYRIGHT AND LICENSE
 
