@@ -13,11 +13,12 @@ package Printer::ESCPOS::Profiles::SinocanPSeries;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 # Dependencies
 use 5.010;
 use Moose;
+extends 'Printer::ESCPOS::Profiles::Generic';
 with 'Printer::ESCPOS::Roles::Profile';
 use namespace::autoclean;
 
@@ -36,11 +37,11 @@ Printer::ESCPOS::Profiles::SinocanPSeries - Sinocan P Series Profile for Printer
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 AUTHOR
 
-Shantanu Bhadoria (shantanu@cpan.org)
+Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
 =head1 COPYRIGHT AND LICENSE
 
