@@ -13,7 +13,7 @@ package Printer::ESCPOS::Roles::Connection;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 # Dependencies
 
@@ -36,14 +36,22 @@ sub write {
 sub print {
     my ( $self, $raw ) = @_;
     my @chunks;
-    my $buffer = $self->_buffer;
-    my $n      = 64;               # Size of each chunk in bytes
 
-    @chunks = unpack "a$n" x ( ( length($buffer) / $n ) - 1 ) . "a*", $buffer;
+    my $printString;
+    if ( defined $raw ) {
+        $printString = $raw;
+    }
+    else {
+        $printString = $self->_buffer;
+        $self->_buffer('');
+    }
+    my $n = 64;    # Size of each chunk in bytes
+
+    @chunks = unpack "a$n" x ( ( length($printString) / $n ) - 1 ) . "a*",
+      $printString;
     for my $chunk (@chunks) {
         $self->_connection->write($chunk);
     }
-    $self->_buffer('');
 }
 
 1;
@@ -58,7 +66,7 @@ Printer::ESCPOS::Roles::Connection - Role for Connection Classes for Printer::ES
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 METHODS
 
@@ -68,11 +76,14 @@ Writes prepared data to the module buffer. This data is dispatched to printer wi
 
 =head2 print
 
-Sends buffer data to the printer.
+If a string is passed then it passes the string to the printer else passes the buffer data to the printer and clears the buffer.
+
+    $device->printer->print(); # Prints and clears the Buffer.
+    $device->printer->print($raw); # Prints $raw 
 
 =head1 AUTHOR
 
-Shantanu Bhadoria (shantanu@cpan.org)
+Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
 =head1 COPYRIGHT AND LICENSE
 
