@@ -13,11 +13,12 @@ package Printer::ESCPOS::Roles::Profile;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 # Dependencies
 use 5.010;
 use Moose::Role;
+requires 'init';
 
 
 has driver => (
@@ -102,7 +103,7 @@ Printer::ESCPOS::Roles::Profile - Role for all Printer Profiles for Printer::ESC
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 ATTRIBUTES
 
@@ -134,6 +135,8 @@ set unset double width property
 
 Set/unset underline property
 
+=head1 METHODS
+
 =head2 write
 
 Sends raw data to the local buffer ready for sending this to the printer. This would contain a set of strings to print or ESCPOS Codes.
@@ -148,7 +151,7 @@ Reads n bytes from the printer. This function is used internally to get printer
 
 =head1 AUTHOR
 
-Shantanu Bhadoria (shantanu@cpan.org)
+Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
 =head1 COPYRIGHT AND LICENSE
 
